Server Class (pysqueezecenter.player.Server) — PySqueezeCenter v0.91 documentation

### Navigation

- index
- next |
- previous |
- PySqueezeCenter v0.91 documentation »

# Server Class (pysqueezecenter.player.Server)

The Server class deals with the SqueezeCenter server and provides the main communication functions between the PySqueezeCenter API and the SqueezeCenter’s Telnet server.

class `pysqueezecenter.server.` `Server`(hostname='localhost', port=9090, username='', password='')

  SqueezeCenter Server

  `connect`()
    Connect
  `get_player`(ref=None)
    Get Player
  `get_player_count`()
    Get Number Of Players
  `get_players`()
    Get Players
  `get_version`()
    Get Version
  `login`()
    Login
  `request`(command_string)
    Request
  `telnet_connect`()
    Telnet Connect

### Navigation

- index
- next |
- previous |
- PySqueezeCenter v0.91 documentation »